@@ -10,6 +10,7 @@
 #include <ctype.h>
 #include <stdio.h>
 #include <math.h>
+#include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -42,7 +43,7 @@ NETLIST FailedNets;	// list of nets that failed to route
 
 u_int    *Obs[MAX_LAYERS];      // net obstructions in layer
 PROUTE   *Obs2[MAX_LAYERS];     // used for pt->pt routes on layer
-float    *Obsinfo[MAX_LAYERS];  // temporary array used for detailed obstruction info
+ObsInfoRec *Obsinfo[MAX_LAYERS];  // temporary array used for detailed obstruction info
 NODEINFO *Nodeinfo[MAX_LAYERS]; // nodes and stub information is here. . .
 DSEG      UserObs;		// user-defined obstruction layers
 
@@ -229,6 +230,10 @@ countlist(NETLIST net)
    return count;
 }
 
+/* Forward declaration */
+
+static void helpmessage(void);
+
 /*--------------------------------------------------------------*/
 /* runqrouter - main program entry point, parse command line	*/
 /*								*/
@@ -835,8 +840,8 @@ static int post_def_setup()
 
    for (i = 0; i < Num_layers; i++) {
 
-      Obsinfo[i] = (float *)calloc(NumChannelsX * NumChannelsY,
-			sizeof(float));
+      Obsinfo[i] = (ObsInfoRec *)calloc(NumChannelsX * NumChannelsY,
+			sizeof(ObsInfoRec));
       if (!Obsinfo[i]) {
 	 fprintf(stderr, "Out of memory 5.\n");
 	 exit(5);
@@ -876,9 +881,6 @@ static int post_def_setup()
    /* want improperly defined or positioned obstruction layers to over-	*/
    /* write our node list.						*/
 
-#ifdef TCL_QROUTER
-   find_free_antenna_taps(antenna_cell);
-#endif
    expand_tap_geometry();
    clip_gate_taps();
    create_obstructions_from_gates();
@@ -1557,6 +1559,11 @@ free_glist(struct routeinfo_ *iroute)
    }
 }
 
+/* Forward declarations */
+
+static int next_route_setup(struct routeinfo_ *iroute, u_char stage);
+static int route_setup(struct routeinfo_ *iroute, u_char stage);
+
 /*--------------------------------------------------------------*/
 /* doroute - basic route call					*/
 /*								*/
