@@ -40,7 +40,7 @@ typedef unsigned long  u_long;
 #endif /* _SYS_TYPES_H */
 
 /* Compare functions aren't defined in the Mac's standard library */
-#if defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
 typedef int (*__compar_fn_t)(const void*, const void*);
 #endif
 
@@ -98,6 +98,13 @@ typedef struct scalerec_ {
    double oscale;
 } ScaleRec;
 
+// structure to hold two offset values, one for x offset, one for y offset
+
+typedef struct obsinforec_ {
+    float xoffset;
+    float yoffset;
+} ObsInfoRec;
+
 // define a structure containing x, y, and layer
 
 typedef struct gridp_ GRIDP;
@@ -445,7 +452,7 @@ extern NET    *Nlnets;
 extern u_char *RMask;
 extern u_int  *Obs[MAX_LAYERS];		// obstructions by layer, y, x
 extern PROUTE *Obs2[MAX_LAYERS]; 	// working copy of Obs 
-extern float  *Obsinfo[MAX_LAYERS];	// temporary detailed obstruction info
+extern ObsInfoRec *Obsinfo[MAX_LAYERS];	// temporary detailed obstruction info
 extern NODEINFO *Nodeinfo[MAX_LAYERS];	// stub route distances to pins and
 					// pointers to node structures.
 
@@ -490,11 +497,8 @@ extern char *antenna_cell;
 /* Function prototypes */
 
 void update_mscale(int mscale);
-static int next_route_setup(struct routeinfo_ *iroute, u_char stage);
-static int route_setup(struct routeinfo_ *iroute, u_char stage);
 int route_segs(struct routeinfo_ *iroute, u_char stage, u_char graphdebug);
 ROUTE createemptyroute(void);
-static void helpmessage(void);
 
 int    set_num_channels(void);
 int    allocate_obs_array(void);
@@ -505,6 +509,16 @@ void   apply_drc_blocks(int, double, double);
 void   remove_top_route(NET net);
 char  *get_annotate_info(NET net, char **pinptr);
 
+void   free_glist(struct routeinfo_ *iroute);
+
+#ifdef TCL_QROUTER
+void   find_free_antenna_taps(char *antennacell);
+#endif
+
+void   resolve_antenna(char *antennacell, u_char do_fix);
+
+void   createMask(NET net, u_char slack, u_char halo);
+void   createBboxMask(NET net, u_char halo);
 
 int    read_def(char *filename);
 
